@@ -23,14 +23,7 @@ set -x
 
 # --can connect always returns true.
 
-requires $NBDKIT --no-sr null --version
+requires $NBDKIT null --version
 
 $NBDKIT -v -U - null \
         --run '$VG nbdinfo --can connect "nbd+unix:///?socket=$unixsocket"'
-
-# --is tls is false for unencrypted connections.
-
-st=0
-$NBDKIT -v -U - null \
-        --run '$VG nbdinfo --is tls "nbd+unix:///?socket=$unixsocket"' || st=$?
-test $st = 2
