@@ -70,6 +70,11 @@ nbd_create (void)
 
   h->unique = 1;
   h->tls_verify_peer = true;
+  h->tls_priority = strdup (TLS_PRIORITY);
+  if (h->tls_priority == NULL) {
+    set_error (errno, "strdup");
+    goto error1;
+  }
   h->request_eh = true;
   h->request_sr = true;
   h->request_meta = true;
@@ -78,6 +83,7 @@ nbd_create (void)
 
   h->uri_allow_transports = LIBNBD_ALLOW_TRANSPORT_MASK;
   h->uri_allow_tls = LIBNBD_TLS_ALLOW;
+  h->uri_allow_tls_priority = false;
   h->uri_allow_local_file = false;
 
   h->gflags = LIBNBD_HANDSHAKE_FLAG_MASK;
@@ -115,6 +121,7 @@ nbd_create (void)
  error1:
   if (h) {
     free (h->export_name);
+    free (h->tls_priority);
     free (h->hname);
     free (h);
   }
@@ -172,6 +179,7 @@ nbd_close (struct nbd_handle *h)
   free (h->export_name);
   free (h->sact_name);
   free (h->tls_certificates);
+  free (h->tls_priority);
   free (h->tls_username);
   free (h->tls_hostname);
   free (h->tls_psk_file);
@@ -329,6 +337,7 @@ nbd_unlocked_get_handle_size (struct nbd_handle *h)
     + estimate_string (h->tls_username)
     + estimate_string (h->tls_hostname)
     + estimate_string (h->tls_psk_file)
+    + estimate_string (h->tls_priority)
     + estimate_string (h->canonical_name)
     + estimate_string (h->description)
     + (h->sock ? sizeof *h->sock : 0)
@@ -730,6 +739,13 @@ nbd_unlocked_set_uri_allow_tls (struct nbd_handle *h, int tls)
   return 0;
 }
 
+int
+nbd_unlocked_set_uri_allow_tls_priority (struct nbd_handle *h, bool allow)
+{
+  h->uri_allow_tls_priority = allow;
+  return 0;
+}
+
 int
 nbd_unlocked_set_uri_allow_local_file (struct nbd_handle *h, bool allow)
 {
