@@ -414,10 +414,11 @@ nbd_internal_printable_string_list (char **list)
 
 }
 
-int nbd_internal_socket (int domain,
-                         int type,
-                         int protocol,
-                         bool nonblock)
+int
+nbd_internal_socket (int domain,
+                     int type,
+                     int protocol,
+                     bool nonblock)
 {
   int fd;
 
