@@ -34,6 +34,7 @@
 #include "requires.h"
 
 #define DEBUG_FILE "socket-activation-name.out"
+#define NAME "hellomagicname"
 
 int
 main (int argc, char *argv[])
@@ -41,15 +42,13 @@ main (int argc, char *argv[])
   struct nbd_handle *nbd;
   char *r;
 
-  /* Test that this version of nbdkit supports -D nbdkit.environ=1
-   * added in nbdkit 1.35.2.
-   *
-   * As a side-effect, also checks we have nbdkit, the null plugin and
-   * a working grep command, all needed below.
+  /* This requires nbdkit >= 1.48 (actually 1.47.5) which prints the
+   * socket activation name in debugging output.
    */
-  requires ("libnbd_sentinel=42 "
-            NBDKIT " -v -D nbdkit.environ=1 null --run true 2>&1 | "
-            "grep -sq 'debug.*libnbd_sentinel=42'");
+  requires (NBDKIT " --version");
+  requires ("minor=$( " NBDKIT " --dump-config |\n"
+            "        grep ^version_minor | cut -d= -f2 )\n"
+            "test $minor -ge 48");
 
   nbd = nbd_create ();
   if (nbd == NULL) {
@@ -63,48 +62,25 @@ main (int argc, char *argv[])
   assert (strcmp (r, "") == 0);
   free (r);
 
-  /* Run external nbdkit and check the LISTEN_FDNAMES environment
-   * variable is set to "unknown".  We need to capture the debug
-   * output of nbdkit, hence the journey through the shell.
+  /* Check we can set it to something and read that back. */
+  assert (nbd_set_socket_activation_name (nbd, NAME) == 0);
+  r = nbd_get_socket_activation_name (nbd);
+  assert (r != NULL);
+  assert (strcmp (r, NAME) == 0);
+  free (r);
+
+  /* Run external nbdkit.  Capture the debug output of nbdkit, hence
+   * the journey through the shell.
    */
   unlink (DEBUG_FILE);
   char *cmd[] = {
     "sh", "-c",
     "exec 2> " DEBUG_FILE "\n"
-    "exec " NBDKIT " --exit-with-parent -v -D nbdkit.environ=1 null 1024\n",
+    "exec " NBDKIT " --exit-with-parent -v null 1024\n",
     NULL
   };
-  if (nbd_connect_systemd_socket_activation (nbd, cmd) == -1) {
-    fprintf (stderr, "%s\n", nbd_get_error ());
-    exit (EXIT_FAILURE);
-  }
 
-  /* Check the size is expected so we know we managed to connect to nbdkit. */
-  assert (nbd_get_size (nbd) == 1024);
-
-  nbd_close (nbd);
-
-  /* nbdkit doesn't know anything about socket activation names, but
-   * the LISTEN_FDNAMES environment variable should appear in the
-   * debug output.
-   */
-  assert (system ("grep 'debug.*LISTEN_FDNAMES=unknown' " DEBUG_FILE) == 0);
-  unlink (DEBUG_FILE);
-
-  /* Test again with a specific name. */
-  nbd = nbd_create ();
-  if (nbd == NULL) {
-    fprintf (stderr, "%s\n", nbd_get_error ());
-    exit (EXIT_FAILURE);
-  }
-  /* Check we can set it to something and read that back. */
-  assert (nbd_set_socket_activation_name (nbd, "hello") == 0);
-  r = nbd_get_socket_activation_name (nbd);
-  assert (r != NULL);
-  assert (strcmp (r, "hello") == 0);
-  free (r);
-
-  /* Run external nbdkit again (same command as above). */
+  /* Run external nbdkit. */
   if (nbd_connect_systemd_socket_activation (nbd, cmd) == -1) {
     fprintf (stderr, "%s\n", nbd_get_error ());
     exit (EXIT_FAILURE);
@@ -114,8 +90,8 @@ main (int argc, char *argv[])
 
   nbd_close (nbd);
 
-  /* Check LISTEN_FDNAMES was set to the known value. */
-  assert (system ("grep 'debug.*LISTEN_FDNAMES=hello' " DEBUG_FILE) == 0);
+  /* Check the name appears in the output. */
+  assert (system ("grep 'debug.*" NAME "' " DEBUG_FILE) == 0);
   unlink (DEBUG_FILE);
 
   exit (EXIT_SUCCESS);
